@@ -158,7 +158,9 @@ FEATURE_FLAGS = [
       "'typing.Tuple' compatibility.")),
     ("--strict-parameter-checks", False,
      "Enable exhaustive checking of function parameter types."),
-    ("--enable-typed-dicts", False,
+    ("--enable-nested-classes", False,
+     "Enable support for nested classes in .py files."),
+    ("--enable-typed-dicts", True,
      "Enable support for TypedDicts."),
     ("--strict-primitive-comparisons", False,
      "Emit errors for comparisons between incompatible primitive types."),
