@@ -442,7 +442,7 @@ class ErrorLogBase:
 
   def unique_sorted_errors(self):
     """Gets the unique errors in this log, sorted on filename and lineno."""
-    unique_errors = collections.OrderedDict()
+    unique_errors = {}
     for error in self._sorted_errors():
       error_without_traceback = str(error.drop_traceback())
       if error_without_traceback not in unique_errors:
@@ -1021,7 +1021,17 @@ class ErrorLog(ErrorLogBase):
     if name:
       return f"'{name}: {typ}'"
     elif len(var.data) == 1 and hasattr(val, "pyval"):
-      return f"'{val.pyval!r}: {typ}'"
+      # For PythonConstants, we want to print the underlying Python value.
+      # But for everything else (e.g. Variables) just use "...".
+      # This provides clearer error messages that show the exact values that
+      # are related to the error while preventing implementation details from
+      # leaking into error messages.
+      def _ellipsis_printer(val):
+        if isinstance(val, mixin.PythonConstant):
+          return val.str_of_constant(_ellipsis_printer)
+        return "..."
+      name = _ellipsis_printer(val)
+      return f"'{name}: {typ}'"
     else:
       return f"'{typ}'"
 
