@@ -126,10 +126,11 @@ class TypedDictBuilder(abstract.PyTDClass):
   def make_class_from_pyi(self, cls_name, pytd_cls, total=True):
     """Make a TypedDictClass from a pyi class."""
     # NOTE: Returns the abstract class, not a variable.
+    name = pytd_cls.name or cls_name
     if total is None:
       total = True
     props = TypedDictProperties(
-        name=cls_name, fields={}, required=set(), total=total)
+        name=name, fields={}, required=set(), total=total)
 
     for c in pytd_cls.constants:
       typ = self.ctx.convert.constant_to_var(c.type)
@@ -177,12 +178,15 @@ class TypedDictClass(abstract.PyTDClass):
       ret.set_str_item(node, k, v)
     return ret
 
-  def instantiate(self, node, container=None):
+  def instantiate_value(self, node, container):
     args = function.Args(())
     for name, typ in self.props.fields.items():
       args.namedargs[name] = self.ctx.join_variables(
           node, [t.instantiate(node) for t in typ.data])
-    return self._new_instance(container, node, args).to_variable(node)
+    return self._new_instance(container, node, args)
+
+  def instantiate(self, node, container=None):
+    return self.instantiate_value(node, container).to_variable(node)
 
   def make_class(self, *args, **kwargs):
     return self._base_cls.make_class(*args, **kwargs)
